@@ -1,11 +1,11 @@
-# @(#)$Id: Crypt.pm 235 2012-11-13 20:51:23Z pjf $
+# @(#)$Id: Crypt.pm 236 2012-12-04 20:05:42Z pjf $
 
 package Class::Usul::Crypt;
 
 use strict;
 use warnings;
 use namespace::clean -except => 'meta';
-use version; our $VERSION = qv( sprintf '0.10.%d', q$Rev: 235 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.11.%d', q$Rev: 236 $ =~ /\d+/gmx );
 
 use Class::Usul::Constants;
 use Class::Usul::Functions qw(create_token is_coderef is_hashref);
@@ -56,7 +56,7 @@ sub __inflate {
 }
 
 sub __compose {
-   __prepare( __deref( $_[ 0 ]->{seed} ) || $SEED ).__deref( $_[ 0 ]->{salt} );
+   __prepare( __deref( $_[ 0 ]->{seed} ) // $SEED ).__deref( $_[ 0 ]->{salt} );
 }
 
 sub __deref {
@@ -68,7 +68,7 @@ sub __prepare {
 }
 
 sub __whiten {
-   my $y = $_[ 0 ]; $y =~ tr{ \t}{01}; $y = pack 'b*', $y; eval $y;
+   my $y = $_[ 0 ] or return ''; $y =~ tr{ \t}{01}; $y = pack 'b*', $y; eval $y;
 }
 
 1;
@@ -81,7 +81,7 @@ Class::Usul::Crypt - Encryption/decryption functions
 
 =head1 Version
 
-0.10.$Revision: 235 $
+0.11.$Revision: 236 $
 
 =head1 Synopsis
 
