@@ -1,12 +1,10 @@
-# @(#)$Id: Meta.pm 236 2012-12-04 20:05:42Z pjf $
+# @(#)$Id: Meta.pm 240 2012-12-09 20:09:04Z pjf $
 
 package Class::Usul::Response::Meta;
 
-use strict;
-use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.11.%d', q$Rev: 236 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.11.%d', q$Rev: 240 $ =~ /\d+/gmx );
 
-use Moose;
+use Class::Usul::Moose;
 use YAML::Syck;
 
 has 'abstract' => is => 'ro', isa => 'Maybe[Str]';
@@ -34,7 +32,7 @@ Class::Usul::Response::Meta - Class for CPAN Meta file
 
 =head1 Version
 
-This document describes Class::Usul::Response::Meta version 0.11.$Revision: 236 $
+This document describes Class::Usul::Response::Meta version 0.11.$Revision: 240 $
 
 =head1 Synopsis
 
